@@ -5,12 +5,12 @@ L{AEChooser}.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import Base, Constants
@@ -35,7 +35,7 @@ class ChooserChange(Base.AccessEngineEvent):
   @ivar kwargs: Aribitrary data to be passed to the handler of this event
   @type kwargs: dictionary
   '''
-  Constants.registerEventType('ChooserGesture', False)
+  Constants.registerEventType('ChooserChange', False)
   def __init__(self, aid, chooser, kind, **kwargs):
     '''
     Stores important references.
