@@ -4,12 +4,12 @@ Defines the abstract base class for all L{AEInput} subclasses.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import logging
 import UIElement
@@ -37,28 +37,42 @@ class AEInput(UIElement.UIE):
     Initializes the listeners list to empty and sets the ready flag to False.
     '''
     self.listeners = []
-    self.ready = False
 
-  def init(self): 
+  def init(self):
     '''
-    Sets the ready flag to True.
+    Called after the instance is created to initialize the device.
+
+    If called when already initialized, this will restore the device to it's
+    initialized state. May also be called to re-initialize the device after
+    a call to L{close}.
+
+    @raise NotImplementedError: When not overridden in a subclass
+    @raise Error.InitError: When a communication or state problem exists for 
+      the specific device
     '''
-    self.ready = True
+    raise NotImplementedError
+    
+  def getCapabilities(self):
+    '''
+    Gets a list of strings representing the capabilities of this device. 
+    Typical output capabilities include "system input," "braille," "switch,"
+    etc. though others are certainly possible.
+    
+    The L{DeviceManager} will only load a device if another device doesn't
+    already provide all of its capabilities.
+    
+    @return: Lowercase names of output capabilities
+    @rtype: list of string
+    '''
+    raise NotImplementedError
     
   def close(self): 
     '''
-    Sets the ready flag to False.
+    Closes an initialized input device.
+
+    @raise NotImplementedError: When not overridden in a subclass
     '''
-    self.ready = False
-    
-  def isReady(self): 
-    '''
-    Gets the state of the ready flag.
-    
-    @return: Is the input device initialized?
-    @rtype: boolean
-    '''
-    return self.ready
+    raise NotImplementedError
     
   def addInputListener(self, listener):
     '''
@@ -105,38 +119,7 @@ class AEInput(UIElement.UIE):
         listener(gesture, timestamp)
       except Exception:
         log.exception('AEInput exception')
-      
-  def addFilter(self, gestures):
-    '''
-    Abstact method. Adds a L{GestureList} as a filter to this device. How the
-    filter is stored and used is determined by a subclass.
-    
-    @param gestures: L{Gesture}s to possibly filter
-    @type gestures: L{GestureList}
-    @raise NotImplementedError: When this method is not overridden by a subclass
-    '''
-    raise NotImplementedError
-    
-  def removeFilter(self, gestures):
-    '''
-    Abstract method. Removes a L{GestureList} as a filter from this device. How
-    the filter is removed is determined by a subclass.
-    
-    @param gestures: L{Gesture}s to no longer filter
-    @type gestures: L{GestureList}
-    @raise NotImplementedError: When this method is not overridden by a subclass
-    '''
-    raise NotImplementedError
-  
-  def clearFilters(self):
-    '''    
-    Abstract method. Removes all L{GestureList} filters from the device. How the
-    filters are removed is determined by a subclass.
-    
-    @raise NotImplementedError: When this method is not overridden by a subclass
-    '''
-    raise NotImplementedError
-    
+
   def sortGesture(self, gesture):
     '''    
     Abstract method. Sort the provided L{Gesture} according to a sort order
@@ -174,35 +157,3 @@ class AEInput(UIElement.UIE):
     @raise NotImplementedError: When this method is not overridden by a subclass
     '''
     raise NotImplementedError
-    
-  def setLocale(self, loc):
-    '''
-    Abstract method. Sets the locale used for handling input from the user.
-
-    When the exact locale provided is not supported, this will attempt to set
-    an available locale based on the language. And will use the device default
-    when the language is not available. This returns the exact locale set.
-
-    Depending on the device, this should also modify the text content gotten
-    from the user. For Braille devices, this can change which table is
-    used.
-    
-    When a supported locale is specified, the strings returned from
-    L{asString} will reflect this command.
-    
-    @param loc: Name of the locale to set
-    @type loc: string
-    @raise NotImplementedError: When this method is not overridden by a subclass
-    '''
-    raise NotImplementedError
-    
-  def getLocale(self): 
-    '''
-    Abstract method. Gets the current locale in use for the input device.
-
-    @return: The name of the current locale
-    @rtype: string
-    @raise NotImplementedError: When not overridden in a subclass
-    @see: L{setLocale}
-    '''
-    raise NotImplementedError
\ No newline at end of file
