@@ -8,19 +8,15 @@ Concrete classes implementing the methods of L{AEInput} that ship with LSR are
 not located in this package. Rather, they are stored in the Devices folder and
 referenced by the L{UIRegistrar} when they need to be loaded.
 
-@var DEVICE_TYPES: All subinterfaces that distinguish devices of different 
-  capabilities
-@type DEVICE_TYPES: list of class
-
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 from Base import AEInput
@@ -28,6 +24,25 @@ from SystemInput import SystemInput
 from GestureList import GestureList
 from Gesture import Gesture
 from Error import *
+from Constants import *
 import Constants
 
-DEVICE_TYPES = [SystemInput]
\ No newline at end of file
+def getDefaults():
+  '''
+  Suggests the default L{AEOutput}s events to be monitored.
+  
+  @return: Names of defaults to monitor
+  @rtype: list of string
+  '''
+  return Constants.default_types
+  
+def getNames():
+  '''
+  Gets the names of all the L{AEOutput} command types.
+  
+  @return: List of all known L{AEOutput} command names
+  @rtype: list of string
+  '''
+  names = Constants.all_types
+  names.sort()
+  return names
\ No newline at end of file
