@@ -6,12 +6,12 @@ Defines the base class for all L{AEOutput} devices.
 @author: Brett Clippingdale
 @organization: IBM Corporation
 @copyright: Copyright (c) 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import UIElement, Style
 
@@ -21,8 +21,10 @@ class AEOutput(UIElement.UIE):
   LSR should derive from this class and should implement the methods defined
   here.
 
-  All methods defined here raise L{NotImplementedError} to ensure that
-  derived classes create appropriate implementions.
+  All methods defined here raise NotImplementedError to ensure that
+  derived classes create appropriate implementions. Implementing 
+  L{sendStringSync} and L{sendFilename} is optional. The L{DeviceManager} 
+  catches the not implemented exception in these cases.
   
   @cvar DEFAULT_STYLE: Style class to use when constructing a default style
     object for this device. A subclass with configurable device settings should
@@ -44,9 +46,6 @@ class AEOutput(UIElement.UIE):
     device implementing this interface. These characters are replaced with
     blanks in any string sent to the device.
   @type COMMAND_CHARS: string
-  @ivar listeners: List of callables that should be notified when a marker 
-    inserted with L{sendIndex} is encountered
-  @type listeners: list
   @ivar styles: Mapping from arbitrary, immutable keys to style objects
   @type styles: dictionary
   '''
@@ -57,14 +56,27 @@ class AEOutput(UIElement.UIE):
 
   def __init__(self):
     '''
-    Initializes the empty listeners list.
+    Initializes the styles dictionary and default style object.
     '''
-    self.listeners = []
     self.styles = {}
     # instantiate an instance of the DEFAULT_STYLE class; it may be filled with 
     # data when preInit is called
     self.default_style = self.DEFAULT_STYLE()
     
+  def getCapabilities(self):
+    '''
+    Gets a list of strings representing the capabilities of this device. 
+    Typical output capabilities include "audio" and "braille" though others are
+    certainly possible.
+    
+    The L{DeviceManager} will only load a device if another device doesn't
+    already provide all of its capabilities.
+    
+    @return: Lowercase names of output capabilities
+    @rtype: list of string
+    '''
+    raise NotImplementedError
+    
   def postInitOutput(self, sett_man):
     '''
     Loads persisted style objects from disk. Called after the L{init} method
@@ -95,20 +107,48 @@ class AEOutput(UIElement.UIE):
     '''
     # use the settings manager to try to persist styles
     sett_man.saveStyles(self.getClassName(), self.default_style, self.styles)
-
-  def init(self):
+  
+  def setStyle(self, key, style):
     '''
-    Called after the instance is created to initialize the device.
-
-    If called when already initialized, this will restore the device to it's
-    initialized state. May also be called to re-initialize the device after
-    a call to L{close}.
-
-    @raise NotImplementedError: When not overridden in a subclass
-    @raise Error.InitError: When a communication or state problem exists for 
-      the specific device
+    Stores the style object under the given key. The style object should be
+    one previously generated by this device (e.g. using 
+    L{createDistinctStyles}) but it is not an enforced requirement. Always
+    makes the style clean before storing it.
+    
+    @param key: Any immutable object
+    @type key: immutable
+    @param style: L{AEOutput} subclass of L{AEState}
+    @type style: L{AEState}
     '''
-    raise NotImplementedError
+    style.makeClean()
+    self.styles[key] = style
+    
+  def getStyle(self, key):
+    '''
+    Gets the style object stored under the given key. If the key is unknown,
+    returns an empty flyweight backed by the default style and stores the
+    new style in L{styles}.
+    
+    @param key: Any immutable object
+    @type key: immutable
+    @return: L{AEOutput} subclass of L{AEState}
+    @rtype: L{AEState}
+    '''
+    try:
+      return self.styles[key]
+    except KeyError:
+      st = self.FLYWEIGHT_STYLE(self.default_style)
+      self.styles[key] = st
+      return st
+  
+  def getDefaultStyle(self):
+    '''
+    Gets the default style of the device.
+    
+    @return: Default style of the device
+    @rtype: L{AEOutput.Style}
+    '''
+    return self.default_style
   
   def createDistinctStyles(self, num_groups, num_layers):
     '''
@@ -154,47 +194,19 @@ class AEOutput(UIElement.UIE):
     '''
     raise NotImplementedError
   
-  def setStyle(self, key, style):
+  def init(self):
     '''
-    Stores the style object under the given key. The style object should be
-    one previously generated by this device (e.g. using 
-    L{createDistinctStyles}) but it is not an enforced requirement. Always
-    makes the style clean before storing it.
-    
-    @param key: Any immutable object
-    @type key: immutable
-    @param style: L{AEOutput} subclass of L{AEState}
-    @type style: L{AEState}
+    Called after the instance is created to initialize the device.
+
+    If called when already initialized, this will restore the device to it's
+    initialized state. May also be called to re-initialize the device after
+    a call to L{close}.
+
+    @raise NotImplementedError: When not overridden in a subclass
+    @raise Error.InitError: When a communication or state problem exists for 
+      the specific device
     '''
-    style.makeClean()
-    self.styles[key] = style
-    
-  def getStyle(self, key):
-    '''
-    Gets the style object stored under the given key. If the key is unknown,
-    returns an empty flyweight backed by the default style and stores the
-    new style in L{styles}.
-    
-    @param key: Any immutable object
-    @type key: immutable
-    @return: L{AEOutput} subclass of L{AEState}
-    @rtype: L{AEState}
-    '''
-    try:
-      return self.styles[key]
-    except KeyError:
-      st = self.FLYWEIGHT_STYLE(self.default_style)
-      self.styles[key] = st
-      return st
-  
-  def getDefaultStyle(self):
-    '''
-    Gets the default style of the device.
-    
-    @return: Default style of the device
-    @rtype: L{AEOutput.Style}
-    '''
-    return self.default_style
+    raise NotImplementedError
 
   def close(self):
     '''
@@ -215,157 +227,39 @@ class AEOutput(UIElement.UIE):
     @raise NotImplementedError: When not overridden in a subclass
     '''
     raise NotImplementedError
-
-  def sendString(self, text, style):
-    '''
-    Sends a string of one or more characters to the device.
-
-    Depending on the device and it's features, the character may first be
-    buffered until either "enough" characters and commands have been
-    received, or L{sendTalk} has been called. To guard against sending
-    unintended commands, the class implementing this method should remove all
-    L{COMMAND_CHARS} from the text.
-
-    @param text: Text to send to the device
-    @type text: string
-    @param style: Style with which this text should be output
-    @type style: L{AEOutput.Style}
-    @raise NotImplementedError: When not overridden in a subclass
-    '''
-    raise NotImplementedError
   
-  def sendFilename(self, fn, style):
-    '''
-    Sends a string filename to the device, the contents of which should be 
-    output.
+  def send(self, name, value, style=None):
+    '''    
+    Sends arbitrary data to a device. The device must recognize the name in
+    order to decide what to do with the value data. If given, the style object
+    is used to decide how the data should be presented if it is content to be
+    rendered.
     
-    Typically, this method should be implemented by an audio device that 
-    supports playback of waveform or sequencer files. It might also be used
-    by devices as a way of synthesizing the entire contents of a file without
-    having to pass all of the contents through the rest of the system.
+    This is a generic method which receives all content and commands to be 
+    rendered and executed on a device. Standard name identifiers should be 
+    used whenever possible. For instance, L{AEOutput.Constants.CMD_STOP} and
+    L{AEOutput.Constants.CMD_TALK}. However, device specific names and values
+    are certainly possible.
     
-    @param fn: Absolute filename
-    @type fn: string
-    @param style: Style with which this text should be output
+    @param name: Descriptor of the data value sent
+    @type name: object
+    @param value: Content value
+    @type value: object
+    @param style: Style with which this value should be output
     @type style: L{AEOutput.Style}
+    @return: Return value specific to the given command
+    @rtype: object
     @raise NotImplementedError: When not overridden in a subclass
     '''
     raise NotImplementedError
-
-  def sendStop(self, style=None):
-    '''
-    Purges buffered text and styles, and interrupts current output.
-
-    @param style: Style indicating which channel on which the stop should be 
-      performed; None indicates stop on all channels
-    @type style: L{AEOutput.Style}
-    @raise NotImplementedError: When not overridden in a subclass
-    '''
-    raise NotImplementedError
-
-  def sendTalk(self, style=None):
-    '''
-    Indicates all text buffered by L{sendString} should now be output. 
-    For devices that do the buffering in the driver, this action may mean simply 
-    sending the command. For devices that do not buffer, this action means 
-    sending text and styles buffered in the LSR device definition.
-
-    @param style: Style indicating which channel on which the talk should be 
-      performed; None indicates talk on all channels
-    @type style: L{AEOutput.Style}
-    @raise NotImplementedError: When not overridden in a subclass
-    '''
-    raise NotImplementedError
-    
-  def sendIndex(self, style):
-    '''
-    Inserts a marker in the output stream. The device should notify all 
-    listeners when the marker is reached. The marker is typically a 
-    monotonically increase integer number mod the maximum integer value 
-    supported by the device.
-    
-    @param style: Style indicating which channel on which the marker should be 
-      inserted
-    @type style: L{AEOutput.Style}
-    @return: Unique marker identifying the index inserted
-    @rtype: integer
-    @raise NotImplementedError: When not overridden in a subclass
-    '''
-    raise NotImplementedError
-
-  def sendStringSync(self, text, style=None, stop=True):
-    '''
-    Sends a complete string to a device followed by a talk command to output it
-    immediately. Blocks until the text has finished being spoken.
-    
-    Do B{not} use this method in place of L{sendString} for normal device 
-    operation. It is intended as a method for doing device output pre-runtime
-    (e.g. when debugging).
-    
-    @param text: String to send to the device
-    @type text: string
-    @param style: Style on which this string should be output; None implies some
-      reasonable default should be used
-    @type style: L{AEOutput.Style}
-    @param stop: Stop current output before doing this output?
-    @type stop: boolean
-    @raise NotImplementedError: When not overridden in a subclass
-    '''
-    raise NotImplementedError
-    
-  def addIndexListener(self, listener):
-    '''
-    Adds a listener that should be notified when speech has progressed to the 
-    point where a marker was inserted with L{sendIndex}.
-    
-    @param listener: The method that should be called when markers received.
-    @type listener: callable
-    '''
-    self.listeners.append(listener)
-
-  def removeIndexListener(self, listener):
-    '''
-    Removes the specified listener.
-    
-    @param listener: The method that should no longer be called when markers 
-      received.
-    @type listener: callable
-    @raise ValueError: When the given listener is not already registered
-    '''
-    self.listeners.remove(listener)
   
   def isActive(self):
     '''
-    Indicates whether the device is active (giving output) or not.
+    Indicates whether the device is active (e.g. giving output, has buffered 
+    content to output, is otherwise busy) or not.
 
-    @return: True when content is buffered or the device is outputing
+    @return: True when active, False when not
     @rtype: boolean
     @raise NotImplementedError: When not overriden in a subclass
     '''
     raise NotImplementedError
-  
-  def parseString(self, text, style, por):
-    '''
-    Parses a string to be output based on the provided style. The goal of the 
-    parsing is to:
-    
-      - break the string into words which can be indexed
-      - manipulate the string to affect its presentation
-      - manipulate the style to affect the presentation of one or more words
-    
-    This method returns the list of parsed words, their associated L{POR}s, and
-    their associated styles. When L{POR}s are not available or the style has
-    not be changed for a particular word, None values are inserted into the 
-    respective lists so that all returned lists are of the same length.
-    
-    @param text: Text to be parsed
-    @type text: string
-    @param style: Style object defining how the text should be parsed
-    @type style: L{AEOutput.Style}
-    @param por: Point of regard for the first character in the text, or None if
-      the text is not associated with a POR
-    @type por: L{POR}
-    @return: Parsed words
-    @rtype: 3-tuple of lists of string, L{POR}, L{AEOutput.Style}
-    '''
-    raise NotImplementedError
