@@ -14,12 +14,12 @@ interface on L{pyLinAcc.Accessible} objects.
 @author: Brett Clippingdale
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 from POR import POR
 from AEEvent import *
@@ -56,7 +56,8 @@ AE_MAP = {ViewChange : ['window:activate', 'window:deactivate',
                          'object:column-reordered'],
           ScreenChange : ['object:bounds-changed',
                           'object:text-bounds-changed',
-                          'object:visible-data-changed']
+                          'object:visible-data-changed'],
+          MouseChange : ['mouse:abs', 'mouse:button']
           }
 
 EVENT_HANDLERS = {
@@ -220,7 +221,9 @@ class DefaultEventHandlerAdapter(Adapter):
       method = getattr(self, name)
     except (KeyError, AttributeError):
       # if that fails, try to check the major event type
-      if event.type.major == 'state-changed':
+      if event.type.klass == 'mouse':
+        method = self._handleMouseEvent
+      elif event.type.major == 'state-changed':
         method = self._handleStateEvent
       else:
         return
@@ -425,3 +428,25 @@ class DefaultEventHandlerAdapter(Adapter):
       kind = ScreenChange.VISIBLE_DATA
     por = POR(self.subject, None, 0, incomplete=True)
     return (ScreenChange(por, kind, **kwargs),)
+
+  def _handleMouseEvent(self, event, **kwargs):
+    '''
+    Creates an L{AEEvent.ScreenChange} event in response to a visible data or
+    bounds change on an object or text.
+    
+    @param event: Raw visibility or bounds change event
+    @type event: L{pyLinAcc.Event.Event}
+    @param kwargs: Parameters to be passed to any created L{AEEvent}
+    @type kwargs: dictionary
+    @return: L{AEEvent.ScreenChange} event
+    @rtype: tuple of L{AEEvent}
+    '''
+    major = event.type.major
+    if major == 'abs':
+      return (MouseChange(MouseChange.MOVE, pos=(event.detail1, 
+                                                 event.detail2)),)
+    elif event.type.minor.endswith('p'):
+      kind = MouseChange.PRESS
+    else:
+      kind = MouseChange.RELEASE
+    return (MouseChange(kind, button=int(event.type.minor[0])),)
\ No newline at end of file
