@@ -7,12 +7,12 @@ Table interface but not the Selection interface.
 @author: Eirikur Hallgrimsson
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 from POR import POR
 from AEEvent import *
@@ -64,6 +64,8 @@ class TableAccInfoAdapter(ContainerAccInfoAdapter):
     @rtype: integer
     @raise LookupError: When the table or item is no longer valid
     '''
+    if self.item_offset is None:
+      return None
     tab = Interfaces.ITable(self.accessible)
     return tab.getRowAtIndex(self.item_offset)
       
@@ -76,6 +78,8 @@ class TableAccInfoAdapter(ContainerAccInfoAdapter):
     @rtype: integer
     @raise LookupError: When the table or item is no longer valid
     '''
+    if self.item_offset is None:
+      return None
     tab = Interfaces.ITable(self.accessible)
     return tab.getColumnAtIndex(self.item_offset)
 
@@ -109,7 +113,7 @@ class TableAccInfoAdapter(ContainerAccInfoAdapter):
     @raise LookupError: When the table or item is no longer valid
     '''
     tab = Interfaces.ITable(self.accessible)
-    if self.item_offset != None:
+    if self.item_offset is not None:
       row = tab.getRowAtIndex(self.item_offset)
       return tab.getRowDescription(row)
     return None
@@ -124,7 +128,7 @@ class TableAccInfoAdapter(ContainerAccInfoAdapter):
     @raise LookupError: When the table or item is no longer valid
     '''
     tab = Interfaces.ITable(self.accessible)
-    if self.item_offset != None:
+    if self.item_offset is not None:
       col = tab.getColumnAtIndex(self.item_offset)
       return tab.getColumnDescription(col)
     return None
@@ -140,7 +144,6 @@ class TableAccInfoAdapter(ContainerAccInfoAdapter):
     '''
     tab = Interfaces.ITable(self.accessible)
     return (tab.nRows, tab.nColumns)
-
   
 class TableNavAdapter(DefaultNavAdapter):
   '''
@@ -534,6 +537,7 @@ class TableEventHandlerAdapter(DegenerateTableEventHandlerAdapter):
     @rtype: tuple of L{AEEvent}
     '''
     # build a focus event
+    kwargs['focused'] = True
     por = POR(self.subject, None, 0)
     focus_event = FocusChange(por, True, **kwargs)
 
