@@ -6,12 +6,12 @@ the Table and the Selection interfaces.
 @author: Eirikur Hallgrimsson
 @organization: IBM Corporation
 @copyright: Copyright (c) 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import pyLinAcc
@@ -99,8 +99,8 @@ class TreeNavAdapter(DefaultNavAdapter):
   Overrides L{DefaultNavAdapter} to provide navigation over tree cells as items.
   Expects the subject to be a L{POR}.
   
-  Adapts subject accessibles that provide the L{pyLinAcc.Interfaces.ISelection},
-  L{pyLinAcc.Interfaces.ITable} interfaces and have ROLE_TREE_TABLE.
+  Adapts subject accessibles that provide the L{pyLinAcc.Interfaces.ITable} 
+  interface and have ROLE_TREE_TABLE.
   '''
   provides = [IAccessibleNav, IItemNav]
 
@@ -156,8 +156,6 @@ class TreeNavAdapter(DefaultNavAdapter):
     Gets the next item relative to the one indicated by the L{POR}
     providing this interface.
 
-    Currently, this assumes only_visible is True.
-    
     @todo: PP: support header nav
     
     @param only_visible: True when Item in the returned L{POR} must be visible
@@ -202,9 +200,7 @@ class TreeNavAdapter(DefaultNavAdapter):
     '''
     Gets the previous item relative to the one indicated by the L{POR} providing
     this interface. 
-    
-    Currently, this assumes only_visible is True.
-    
+
     @todo: PP: support header nav
     
     @param only_visible: True when Item in the returned L{POR} must be visible
