@@ -1,6 +1,6 @@
 '''
-Defines a class representing a standard L{Keyboard} input device and action code
-constants used to register filters on that device.
+Defines a class representing a standard L{Keyboard} input device and action 
+code constants used to register filters on that device.
 
 @var MAX_KEY_CHORD: Maximum number of actions that can be in a keyboard gesture
 @type MAX_KEY_CHORD: integer
@@ -11,12 +11,12 @@ constants used to register filters on that device.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import AEInput, pyLinAcc
 # need pygtk to map keycodes to keynames
@@ -96,14 +96,16 @@ class Keyboard(AEInput.SystemInput):
     are constant.
   @type LOCK_KEYS: list of integer
   '''
-  def __init__(self):
+  def init(self):
     '''
     Initializes the empty filters dictionary and sets the event_manager
     reference to None. Creates an empty L{AEInput.Gesture} that will be used to
     buffer incoming keystrokes until the L{AEInput.Gesture} definitely matches
-    or does not match one of the held filters.
+    or does not match one of the held filters. Registers for key press and 
+    release events via L{pyLinacc}. Sets the filtering mode to handled by
+    default. Also registers for window activate events to account for missing 
+    keys caused by system wide hotkey presses.
     '''
-    AEInput.SystemInput.__init__(self)
     self.filters = {}
     self.stateful = None
     self.event_manager = pyLinAcc.Event.Manager()
@@ -114,15 +116,7 @@ class Keyboard(AEInput.SystemInput):
     self.last_press = False
     self.LOCK_KEYS = [self.AEK_CAPS_LOCK, self.AEK_SCROLL_LOCK, 
                       self.AEK_NUM_LOCK]
-
-  def init(self):
-    '''
-    Initializes the L{Keyboard} device by registering for key press and release
-    events via the L{EventManager}. Sets the filtering mode to handled by
-    default. Also registers for focus events to account for missing keys caused
-    by system wide hotkey presses.
-    '''
-    AEInput.SystemInput.init(self)
+    
     self.event_manager.addClient(self._onKeyPressed, 'keyboard:press')
     self.event_manager.addClient(self._onKeyReleased, 'keyboard:release')
     self.event_manager.addClient(self._onForegroundChange, 'window:activate')
