@@ -9,12 +9,12 @@ accessibles and handling their events.
 @author: Eirikur Hallgrimsson
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 from AccAdapt import Interface
@@ -360,8 +360,8 @@ class IAccessibleInfo(Interface):
     '''
     Gets all of the name:value attribute pairs of an accessible.
     
-    @return: List of name:value pairs in the accessible attributes
-    @rtype: list of string
+    @return: Name:value pairs in the accessible attributes
+    @rtype: dictionary
     @raise LookupError: When the accessible object is dead
     '''
     pass
@@ -502,7 +502,7 @@ class IAccessibleInfo(Interface):
     Gets all of the default text attributes assigned to the subject.
     
     @return: Name:value pairs of the default text attributes
-    @rtype: list of strings
+    @rtype: dictionary
     @raise LookupError: When the accessible object is dead
     '''
     pass
