@@ -22,12 +22,12 @@ See the LSR man pages for help with using command line parameters.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at 
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 try:
   # little bit of fun to see how psyco improves things
@@ -163,13 +163,12 @@ def disassociate(options):
     disassociation
   '''
   # confirm the deletion action
-  vals = (options.action_value, ', '.join(options.profile))
   if not confirmRemove(options.action_value):
-    return _('Cancelled removal of %s from %s') % vals
+    return _('Cancelled removal of %s') % options.action_value
   reg = UIRegistrar
   profiles = reg.disassociate(options.action_value, options.profile, 
                               options.uie_tier, options.uie_all_tiers)
-  return _('%s removed from %s' % vals)
+  return _('%s removed from %s' % (options.action_value, ', '.join(profiles)))
 
 def generate(options):
   '''
