@@ -5,12 +5,12 @@ handle them.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import AEEvent
@@ -88,4 +88,4 @@ class TaskMonitor(GTKEventDialog):
         self._queueText('\ttier: %s\n' % tier_name)
       else:
         self._queueText('\t%s.%s\n' % (perk.getName(), task.getName()))
-        self._queueText('\t\tpropogate: %s\n' % str(propogate))
+        self._queueText('\t\tpropagate: %s\n' % str(propogate))
