@@ -1,24 +1,31 @@
 '''
-Defines the user interface for gaim.
+Defines corrections for the metacity desktop and app switcher.
+
+Event announcements
+
+on cycle windows: [name of window]
+on cycle desktops: [name of desktop]
 
 @author: Brett Clippingdale
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import Perk, Task
 import LSRConstants
 
+__uie__ = dict(kind='perk', tier='metacity')
+
 class MetacityPerk(Perk.Perk):
   '''
-  Supplements the DefaultPerk to announce information in the metacity desktop 
-  and application switcher windows.
+  Announce information in the metacity desktop and application switcher 
+  windows. Supplements the DefaultPerk.
   '''
   def init(self):
     '''   
@@ -26,6 +33,9 @@ class MetacityPerk(Perk.Perk):
     containing the name of the currently selected window in the application or 
     workspace switcher.
     '''
+    # set an audio device as the default output
+    self.setPerkIdealOutput('audio')
+    
     # register event handlers
     self.registerEventTask(HandlePropertyChange(self), tier=True)
 
@@ -38,7 +48,7 @@ class HandlePropertyChange(Task.PropertyTask):
     # get the text in status bar
     text = self.getItemText(por)
     # pretend we're on the focus layer even though text is changing elsewhere
-    self.stopNow(layer=Task.FOCUS_LAYER)
-    self.say(text=text, sem=LSRConstants.SEM_WINDOW, layer=Task.FOCUS_LAYER)
+    self.stopNow(layer=Task.LAYER_FOCUS)
+    self.say(text=text, sem=LSRConstants.SEM_WINDOW, layer=Task.LAYER_FOCUS)
     return True
 
