@@ -5,12 +5,12 @@ Defines L{Tools} that function as a set of utilities.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import Base, LSRConstants
@@ -23,12 +23,13 @@ class Utils(Base.TaskTools):
   '''
   def getColorString(self, val):
     '''
-    Tries to map a given RGB string (if in form "u,u,u") to a nearby color name
+    Tries to map a given RGB string (if in form "u,u,u") to a nearby color 
+    name.
     
-    @param val: representation of an RGB color in form "u,u,u"
+    @param val: Representation of an RGB color in form "u,u,u"
     @type val: string
-    @return: color name if val param is valid format, val otherwise
-    @rtype: string, or val type if val returned
+    @return: Localized color name if val param is valid format, otherwise None
+    @rtype: string
     '''
     # if color value an RGB 3-tuple, map it to a string value
     try:
@@ -107,7 +108,6 @@ class Utils(Base.TaskTools):
     b = b >> 6
     rgb = r+g+b # add into 6-bit bitfield (rrggbb) for integer value 0..63
     name = LSRConstants.COLOR_MAP[rgb] # get the color value from dictionary
-    print "%s mapped to color:%s" % (rgb, name)
     return name
   
  
\ No newline at end of file
