@@ -7,12 +7,12 @@ Defines a class unifying navigation over all accessibles and their items.
 @author: Peter Parente
 @organization: IBM Corporation
 @copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import Base
@@ -383,7 +383,7 @@ class AccessibleItemWalker(Base.Walker):
       por, state = state(por)
     if por is not None:
       self.por = por
-    #print por
+    #print 'STOP', por
     return por
 
   def getPrevPOR(self):
@@ -401,11 +401,11 @@ class AccessibleItemWalker(Base.Walker):
     state = self._getPrevItem
     por = self.por
     while state is not None:
-      print state.func_name, str(por)
+      #print state.func_name, str(por)
       por, state = state(por)
     if por is not None:
       self.por = por
-    print por
+    #print por
     return por
   
   def getFirstPOR(self):
